import customtkinter as ctk
from tkinter import messagebox
from PIL import Image
from utils.api_requests import login_api  # Import the login function from login_api.py

def login_frame(parent, switch_func, API_URL):
    # Create a container frame to hold both left (empty) and right (login) frames
    container = ctk.CTkFrame(parent)
    container.grid_columnconfigure(0, weight=1)  # Left empty frame
    container.grid_columnconfigure(1, weight=1)  # Right login frame
    container.grid_rowconfigure(0, weight=1)

    # Left empty frame (Just an empty frame to balance the layout)
    left_frame = ctk.CTkFrame(container)
    left_frame.grid(row=0, column=0, sticky="nsew")

    # Load and display the image
    image_path = "app/static/front_end_img/login.jpg"  # Change this to your image path
    img = ctk.CTkImage(light_image=Image.open(image_path), size=(1000, 1000))  # Resize as needed
    image_label = ctk.CTkLabel(left_frame, image=img, text="")  # No text, only image
    image_label.place(relwidth=1, relheight=1)
    
    # Right login frame
    right_frame = ctk.CTkFrame(container)
    right_frame.grid(row=0, column=1, sticky="nsew")

    def login():
        email = entry_email.get()
        password = entry_password.get()

        if not email or not password:
            messagebox.showwarning("Input Error", "Both fields are required!")
            return

        # Call the API function from login_api.py
        status_code, response_data = login_api(email, password, API_URL)

        if status_code == 200:
            access_token = response_data.get("access_token")
            messagebox.showinfo("Login Successful", f"Welcome back, {email}!")
            switch_func("view_shop", access_token)
            print(f"Access Token in login: {access_token}")  # Debugging line
        else:
            messagebox.showerror(
                "Login Failed", response_data.get("detail", "Invalid credentials")
            )

    ctk.CTkLabel(right_frame, text="Login", font=("Helvetica", 18, "bold")).pack(pady=10)

    ctk.CTkLabel(right_frame, text="Email:").pack(pady=5)
    entry_email = ctk.CTkEntry(right_frame)
    entry_email.pack(pady=5)

    ctk.CTkLabel(right_frame, text="Password:").pack(pady=5)
    entry_password = ctk.CTkEntry(right_frame, show="*")
    entry_password.pack(pady=5)

    ctk.CTkButton(right_frame, text="Login", command=login).pack(pady=15)

    ctk.CTkButton(
        right_frame,
        text="Don't have an account? Register",
        command=lambda: switch_func("register"),
    ).pack()

    return container
